<?php
namespace Bushelpowered\Api\Platform\Location\V1\Model;
        
class FacilityStandard implements \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceName The record's source name*/
    public ?string $sourceName = null;
    /** @var null|string $internalName The customer or user's name for a location; not for growers*/
    public ?string $internalName = null;
    /** @var null|string $publicName What the grower or a customer's customer will see for location name*/
    public ?string $publicName = null;
    /** @var string $physicalAddressLine1 First line of a standard US postal address*/
    public string $physicalAddressLine1;
    /** @var null|string $physicalAddressLine2 Second line of a standard US postal address*/
    public ?string $physicalAddressLine2 = null;
    /** @var null|string $physicalLocality Physical locality*/
    public ?string $physicalLocality = null;
    /** @var null|string $physicalAdministrativeArea Physical administrative area*/
    public ?string $physicalAdministrativeArea = null;
    /** @var null|string $physicalPostalCode Physical postal code*/
    public ?string $physicalPostalCode = null;
    /** @var null|string $physicalCountryCode Physical country code*/
    public ?string $physicalCountryCode = null;
    /** @var null|float $latitude Latitude*/
    public ?float $latitude = null;
    /** @var null|float $longitude Longitude*/
    public ?float $longitude = null;
    /** @var string[]|null $businessType The list of business types for the location.  Expected options include Grain Delivery, Agronomy, Office, Plant, Seed and Feed*/
    public ?array $businessType = null;
    /** @var null|string $businessPhone Business phone*/
    public ?string $businessPhone = null;
    /** @var null|string $businessFax Business fax*/
    public ?string $businessFax = null;
    /** @var null|string $businessEmail Business Email*/
    public ?string $businessEmail = null;
    /** @var null|string $businessWebsite Business website*/
    public ?string $businessWebsite = null;
    /** @var \Bushelpowered\Api\Platform\Location\V1\Domo\LocationType $locationType */
    public \Bushelpowered\Api\Platform\Location\V1\Domo\LocationType $locationType;
    /** @var \Bushelpowered\Api\Platform\Location\V1\Model\LocationStandard[] $children */
    public array $children;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceName The record's source name
     * @param  null|string  $internalName The customer or user's name for a location; not for growers
     * @param  null|string  $publicName What the grower or a customer's customer will see for location name
     * @param  string  $physicalAddressLine1 First line of a standard US postal address
     * @param  null|string  $physicalAddressLine2 Second line of a standard US postal address
     * @param  null|string  $physicalLocality Physical locality
     * @param  null|string  $physicalAdministrativeArea Physical administrative area
     * @param  null|string  $physicalPostalCode Physical postal code
     * @param  null|string  $physicalCountryCode Physical country code
     * @param  null|float  $latitude Latitude
     * @param  null|float  $longitude Longitude
     * @param  string[]|null  $businessType The list of business types for the location.  Expected options include Grain Delivery, Agronomy, Office, Plant, Seed and Feed
     * @param  null|string  $businessPhone Business phone
     * @param  null|string  $businessFax Business fax
     * @param  null|string  $businessEmail Business Email
     * @param  null|string  $businessWebsite Business website
     * @param  \Bushelpowered\Api\Platform\Location\V1\Domo\LocationType  $locationType 
     * @param  \Bushelpowered\Api\Platform\Location\V1\Model\LocationStandard[]  $children 
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceName, ?string $internalName, ?string $publicName, string $physicalAddressLine1, ?string $physicalAddressLine2, ?string $physicalLocality, ?string $physicalAdministrativeArea, ?string $physicalPostalCode, ?string $physicalCountryCode, ?float $latitude, ?float $longitude, ?array $businessType, ?string $businessPhone, ?string $businessFax, ?string $businessEmail, ?string $businessWebsite, \Bushelpowered\Api\Platform\Location\V1\Domo\LocationType $locationType, array $children, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceName = $sourceName;
        $this->internalName = $internalName;
        $this->publicName = $publicName;
        $this->physicalAddressLine1 = $physicalAddressLine1;
        $this->physicalAddressLine2 = $physicalAddressLine2;
        $this->physicalLocality = $physicalLocality;
        $this->physicalAdministrativeArea = $physicalAdministrativeArea;
        $this->physicalPostalCode = $physicalPostalCode;
        $this->physicalCountryCode = $physicalCountryCode;
        $this->latitude = $latitude;
        $this->longitude = $longitude;
        $this->businessType = $businessType;
        $this->businessPhone = $businessPhone;
        $this->businessFax = $businessFax;
        $this->businessEmail = $businessEmail;
        $this->businessWebsite = $businessWebsite;
        $this->locationType = $locationType;
        $this->children = $children;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}